@@ -65,6 +65,7 @@ pub struct Config {
     pub uda_shortcuts: Vec<String>,
     pub uda_background_process: String,
     pub uda_background_process_period: usize,
+    pub uda_task_report_prompt_on_delete: bool,
 }
 
 impl Config {
@@ -109,6 +110,7 @@ impl Config {
         let uda_style_context_active = uda_style_context_active.unwrap_or_default();
         let uda_style_report_completion_pane =
             uda_style_report_completion_pane.unwrap_or_else(|| Style::default().bg(Color::Rgb(223, 223, 223)));
+        let uda_task_report_prompt_on_delete = Self::get_uda_task_report_prompt_on_delete(data);
 
         Ok(Self {
             enabled,
@@ -141,6 +143,7 @@ impl Config {
             uda_shortcuts,
             uda_background_process,
             uda_background_process_period,
+            uda_task_report_prompt_on_delete,
         })
     }
 
@@ -448,6 +451,13 @@ impl Config {
             .unwrap_or(true)
     }
 
+    fn get_uda_task_report_prompt_on_delete(data: &str) -> bool {
+        Self::get_config("uda.taskwarrior-tui.task-report.prompt-on-delete", data)
+            .unwrap_or_default()
+            .get_bool()
+            .unwrap_or(false)
+    }
+
     fn get_uda_selection_indicator(data: &str) -> String {
         let indicator = Self::get_config("uda.taskwarrior-tui.selection.indicator", data);
         match indicator {
